"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const chai_1 = require("chai");
const utils_1 = require("./utils");
describe('Telegram bot test', () => {
    const token = 'some token';
    it('should return help content', async () => {
        const { server, bot } = await (0, utils_1.getServerAndBot)(token);
        const client = server.getClient(token, { timeout: 5000 });
        const command = client.makeCommand('/start');
        const res = await client.sendCommand(command);
        chai_1.assert.equal(res.ok, true);
        const updates = await client.getUpdates();
        bot.stop();
        await server.stop();
        chai_1.assert.equal(updates.ok, true);
        chai_1.assert.equal(updates.result.length, 1, 'updates queue should contain one message!');
    });
    it('should respond pong to callback_query', async () => {
        const { server, bot } = await (0, utils_1.getServerAndBot)(token);
        const client = server.getClient(token, { timeout: 5000 });
        const cb = client.makeCallbackQuery('ping');
        const res = await client.sendCallback(cb);
        chai_1.assert.equal(res.ok, true);
        const updates = await client.getUpdates();
        bot.stop();
        await server.stop();
        chai_1.assert.equal(updates.ok, true);
        chai_1.assert.equal(updates.result.length, 1, 'updates queue should contain one message!');
        chai_1.assert.equal(updates.result[0].message.text, 'pong', 'message should be pong!');
    });
});
